=========
Changelog
=========

Unreleased
==========
-

Version 0.7.1
=============
- CI and docs updates (new python versions etc.)

Version 0.7.0
=============
- Test download function with real data.
- Support GLDAS EP
- GHA to replace travis
- Update docs
- Update Formatting

Version 0.6.1
=============
- Travis upload release to pypi

Version 0.6
===========
- New package structure
- Drop python 2 support
- Allow subsetting by bbox
- Add gldas land mask to package (no download necessary)

Version 0.5
===========
- Update trollsift parsing
- Update readme
- Support reshuffling of land points only
- Test with netcdf test data

Version 0.4
===========
- Add support for GLDAS version 2.1
- Compress files during reshuffling.

Version 0.3
===========
- Fix download with new URL
- Only download grb and xml files

Version 0.2
===========
- Fix Python 3 bug when iterating over multiple images.
- Add reshuffling to time series format and reading of time series.

Version 0.1
===========
- First release. Support for Downloading and reading GLDAS Noah v1 0.25 degree
  data.
